@@ -1,7 +1,7 @@
 context("periscope create new application")
 
 
-expect_cleanup_create_new_application <- function(fullname, sampleapp = FALSE, dashboard_plus = FALSE, leftsidebar = TRUE) {
+expect_cleanup_create_new_application <- function(fullname, sampleapp = FALSE, dashboard_plus = FALSE, leftsidebar = TRUE, skin = NULL) {
     expect_true(dir.exists(fullname))
     expect_true(file.exists(paste0(fullname, "/global.R")))
     expect_true(file.exists(paste0(fullname, "/server.R")))
@@ -37,6 +37,12 @@ expect_cleanup_create_new_application <- function(fullname, sampleapp = FALSE, d
     } else {
         expect_true(!file.exists(paste0(fullname, "/program/ui_sidebar_right.R")))
     }
+    if (!is.null(skin)) {
+        ui_file    <- file(paste0(fullname, "/ui.R"), open = "r")
+        ui_content <- readLines(con = ui_file)
+        close(ui_file)
+        expect_true(any(grepl(skin, ui_content)))
+    }
 
     # clean up
     unlink(fullname, TRUE)
@@ -73,6 +79,15 @@ test_that("create_new_application sample right_sidebar", {
     expect_cleanup_create_new_application(appTemp, sampleapp = TRUE, dashboard_plus = !is.null(right_sidebar))
 })
 
+test_that("create_new_application sample invalid right_sidebar", {
+    appTemp.dir   <- tempdir()
+    appTemp       <- tempfile(pattern = "TestThatApp", tmpdir = appTemp.dir)
+    appTemp.name  <- gsub('\\\\|/', '', (gsub(appTemp.dir, "", appTemp, fixed = T)))
+    
+    expect_error(create_new_application(name = appTemp.name, location = appTemp.dir, sampleapp = TRUE, rightsidebar = mtcars), 
+                   "Framework creation could not proceed, invalid type for rightsidebar, only logical or character allowed")
+})
+
 test_that("create_new_application no left sidebar", {
     appTemp.dir   <- tempdir()
     appTemp       <- tempfile(pattern = "TestThatApp", tmpdir = appTemp.dir)
@@ -93,6 +108,25 @@ test_that("create_new_application no reset button", {
     expect_cleanup_create_new_application(appTemp, sampleapp = TRUE)
 })
 
+test_that("create_new_application custom style", {
+    appTemp.dir  <- tempdir()
+    appTemp      <- tempfile(pattern = "TestThatApp", tmpdir = appTemp.dir)
+    appTemp.name <- gsub('\\\\|/', '', (gsub(appTemp.dir, "", appTemp, fixed = T)))
+    
+    expect_message(create_new_application(name = appTemp.name, location = appTemp.dir, sampleapp = FALSE, rightsidebar = NULL, style = list(skin = "green")), 
+                   "Framework creation was successful.")
+    expect_cleanup_create_new_application(appTemp, skin = "green")
+})
+
+test_that("create_new_application invalid style", {
+    appTemp.dir  <- tempdir()
+    appTemp      <- tempfile(pattern = "TestThatApp", tmpdir = appTemp.dir)
+    appTemp.name <- gsub('\\\\|/', '', (gsub(appTemp.dir, "", appTemp, fixed = T)))
+    
+    expect_error(create_new_application(name = appTemp.name, location = appTemp.dir, sampleapp = FALSE, rightsidebar = NULL, style = mtcars), 
+                 "Framework creation could not proceed, invalid type for style, only list allowed")
+})
+
 test_that("create_new_application invalid location", {
     expect_warning(create_new_application(name = "Invalid", location = tempfile(), sampleapp = FALSE),
                    "Framework creation could not proceed, location=.* does not exist!")
